==============
Conda commands
==============

The ``conda`` command is the primary interface for managing
installations of various packages. It can:

* Query and search the Anaconda package index and current
  Anaconda installation.

* Create new conda environments.

* Install and update packages into existing conda environments.

.. tip::
   You can abbreviate many frequently used command options that
   are preceded by 2 dashes (``--``) to just 1 dash and the first
   letter of the option. So ``--name`` and ``-n`` are the same, and
   ``--envs`` and ``-e`` are the same.

For full usage of each command, including abbreviations, see
:doc:`../../commands`. You can see the same information at the
command line by :doc:`viewing the command-line help
<../tasks/view-command-line-help>`.
